from __future__ import absolute_import
from __future__ import print_function
import sys
py_rumd_lib = {2:"../../../lib", 3:"../../../lib_py3"}[sys.version_info[0]]
sys.path.insert(1, py_rumd_lib)
sys.path.insert(1, "../../../Python")


import rumd
# it is essential that there is no doubt about which version is actually run!
print("File used to import the rumd module", rumd.__file__)

from rumd.Simulation import Simulation
from rumd.RUMD_Test import RUMD_Test

class Test_Dzugutov (RUMD_Test):
    """
    Single component system with Dzugutov potential and NVE dynamics.
    Tests also: AlternatePotentialCalculator
    """
    def __init__(self):
        RUMD_Test.__init__(self)
        self.numParticlesList = [512, 1000, 8000]
    
    def RunSimulation(self, mode, numParticles, pb, tp):

        # set the number of time-steps depending on the mode (assigned
        # as a class attribute so the calling function can access it later)
        self.numTimeSteps = {"short":          100,
                             "performance": 100000,
                             "stress":   100000000}[mode]
        
        # sample and simulation
        startConfg = "startN%d.xyz.gz" % numParticles

        
        sim = Simulation(startConfg, pb, tp, verbose=False)

        
        if self.generate_reference_data:
            sim.SetOutputDirectory(self.ref_directory)
            sim.SetSortInterval(0)
        else:
            sim.SetOutputDirectory(self.out_directory)

        # integrator
        itg = rumd.IntegratorNVE(timeStep=0.005)

        # Create pair-potential
        potential = rumd.Pot_Dzugutov()
        # i  j  a  b  c  d  A  B
        potential.SetParams(0, 0, 1.87, 1.94, 1.1, 0.27, 5.82, 1.28)
    
        sim.SetIntegrator(itg)
        sim.SetPotential(potential)

        potLJ = rumd.Pot_LJ_12_6(cutoff_method=rumd.ShiftedForce)
        potLJ.SetID_String("potLJ")
        potLJ.SetParams(0, 0, 1.0, 1.0, 2.5)

        alt_pot_calc = rumd.AlternatePotentialCalculator(sim.sample, potLJ)
        sim.AddExternalCalculator(alt_pot_calc)


        # tune output depending on the mode
        if mode == "short":
            sim.SetOutputScheduling("energies","linear",interval=1)
            sim.SetOutputScheduling("trajectory","linear",interval=10)
            sim.SetBlockSize(50)
        elif mode == "stress":
            sim.SetOutputScheduling("energies","linear",interval=5000)
        else:
            assert mode == "performance"
            print("Note there is no output directory for performance test--the only output is the timing file")
            
        sim.Run(self.numTimeSteps,
                suppressAllOutput=(mode == "performance"))


        sim.RemoveExternalCalculator(alt_pot_calc)

if __name__ == "__main__":

    rumd_test = Test_Dzugutov()
      
    # standard short test to be called from makefile
    # For generating reference data and running stress and performance modes
    # there are corresponding scripts to be submitted to pbs

    sys.exit(rumd_test.RunShort("gen_ref" in sys.argv ) )
    
    # for individual runs, could do for example
    #sys.exit(rumd_test.Test("short", 1000, 16, 8))
