from __future__ import absolute_import
from __future__ import division

import sys
import unittest
py_rumd_lib = {2:"../../../lib", 3:"../../../lib_py3"}[sys.version_info[0]]
sys.path.insert(1, py_rumd_lib)
sys.path.insert(1, "../../../Python")

import rumd
from rumd.Simulation import Simulation


class TestShearBoundarySmall(unittest.TestCase):
    """ Class for testing shear for small systems"""
    def setUp(self):
        self.sim = Simulation("traj0076_0038_srt_vel.xyz.gz")


        # Create LJ pair-potential
        self.potential = rumd.Pot_LJ_12_6(cutoff_method=rumd.ShiftedPotential)
        self.potential.SetParams(i=0, j=0, Epsilon=1.0, Sigma=1.0, Rcut=2.5)
        self.potential.SetNbListSkin(0)

        self.sim.SetPotential(self.potential)

        # Molecule stuff
        self.sim.ReadMoleculeData("start_srt.top")
        self.sim.SetBondHarmonic(bond_type=0, lbond=1.0, ks=100.0)

        self.reference_pe = -0.32189828

    def test_unsorted(self):
        """ test where the potential energy is calculated with non-sorting based
        neighbor-list generation"""
        self.sim.sample.CalcF()
        pe = self.sim.sample.GetPotentialEnergy()/self.sim.GetNumberOfParticles()
        #print "pe",pe
        self.assertLess(abs(pe-self.reference_pe), 1.e-6)

    def test_sorted(self):
        """ test where the potential energy is calculated with sorting based
        neighbor-list generation"""
        self.sim.sample.SortParticles()
        self.sim.sample.CalcF()
        pe = self.sim.sample.GetPotentialEnergy()/self.sim.GetNumberOfParticles()

        #print "pe",pe
        self.assertLess(abs(pe-self.reference_pe), 1.e-6)

if __name__ == '__main__':
    unittest.main()
